# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: messages.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


from mesos.interface import mesos_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='messages.proto',
  package='mesos.internal',
  serialized_pb='\n\x0emessages.proto\x12\x0emesos.internal\x1a\x0bmesos.proto\"\x92\x02\n\x04Task\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x1e\n\x07task_id\x18\x02 \x02(\x0b\x32\r.mesos.TaskID\x12(\n\x0c\x66ramework_id\x18\x03 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0b\x65xecutor_id\x18\x04 \x01(\x0b\x32\x11.mesos.ExecutorID\x12 \n\x08slave_id\x18\x05 \x02(\x0b\x32\x0e.mesos.SlaveID\x12\x1f\n\x05state\x18\x06 \x02(\x0e\x32\x10.mesos.TaskState\x12\"\n\tresources\x18\x07 \x03(\x0b\x32\x0f.mesos.Resource\x12#\n\x08statuses\x18\x08 \x03(\x0b\x32\x11.mesos.TaskStatus\"+\n\x08RoleInfo\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x11\n\x06weight\x18\x02 \x01(\x01:\x01\x31\"\xc6\x01\n\x0cStatusUpdate\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0b\x65xecutor_id\x18\x02 \x01(\x0b\x32\x11.mesos.ExecutorID\x12 \n\x08slave_id\x18\x03 \x01(\x0b\x32\x0e.mesos.SlaveID\x12!\n\x06status\x18\x04 \x02(\x0b\x32\x11.mesos.TaskStatus\x12\x11\n\ttimestamp\x18\x05 \x02(\x01\x12\x0c\n\x04uuid\x18\x06 \x02(\x0c\"\xa4\x01\n\x12StatusUpdateRecord\x12\x35\n\x04type\x18\x01 \x02(\x0e\x32\'.mesos.internal.StatusUpdateRecord.Type\x12,\n\x06update\x18\x02 \x01(\x0b\x32\x1c.mesos.internal.StatusUpdate\x12\x0c\n\x04uuid\x18\x03 \x01(\x0c\"\x1b\n\x04Type\x12\n\n\x06UPDATE\x10\x00\x12\x07\n\x03\x41\x43K\x10\x01\"&\n\x16SubmitSchedulerRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"\'\n\x17SubmitSchedulerResponse\x12\x0c\n\x04okay\x18\x01 \x02(\x08\"\x9e\x01\n\x1a\x45xecutorToFrameworkMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\x12(\n\x0c\x66ramework_id\x18\x02 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0b\x65xecutor_id\x18\x03 \x02(\x0b\x32\x11.mesos.ExecutorID\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x0c\"\x9e\x01\n\x1a\x46rameworkToExecutorMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\x12(\n\x0c\x66ramework_id\x18\x02 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0b\x65xecutor_id\x18\x03 \x02(\x0b\x32\x11.mesos.ExecutorID\x12\x0c\n\x04\x64\x61ta\x18\x04 \x02(\x0c\"C\n\x18RegisterFrameworkMessage\x12\'\n\tframework\x18\x01 \x02(\x0b\x32\x14.mesos.FrameworkInfo\"W\n\x1aReregisterFrameworkMessage\x12\'\n\tframework\x18\x02 \x02(\x0b\x32\x14.mesos.FrameworkInfo\x12\x10\n\x08\x66\x61ilover\x18\x03 \x02(\x08\"n\n\x1a\x46rameworkRegisteredMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0bmaster_info\x18\x02 \x02(\x0b\x32\x11.mesos.MasterInfo\"p\n\x1c\x46rameworkReregisteredMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0bmaster_info\x18\x02 \x02(\x0b\x32\x11.mesos.MasterInfo\"F\n\x1aUnregisterFrameworkMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\"F\n\x1a\x44\x65\x61\x63tivateFrameworkMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\"d\n\x16ResourceRequestMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12 \n\x08requests\x18\x02 \x03(\x0b\x32\x0e.mesos.Request\"C\n\x15ResourceOffersMessage\x12\x1c\n\x06offers\x18\x01 \x03(\x0b\x32\x0c.mesos.Offer\x12\x0c\n\x04pids\x18\x02 \x03(\t\"\xc4\x01\n\x12LaunchTasksMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12 \n\x08offer_id\x18\x02 \x01(\x0b\x32\x0e.mesos.OfferID\x12\x1e\n\x05tasks\x18\x03 \x03(\x0b\x32\x0f.mesos.TaskInfo\x12\x1f\n\x07\x66ilters\x18\x05 \x02(\x0b\x32\x0e.mesos.Filters\x12!\n\toffer_ids\x18\x06 \x03(\x0b\x32\x0e.mesos.OfferID\"?\n\x1bRescindResourceOfferMessage\x12 \n\x08offer_id\x18\x01 \x02(\x0b\x32\x0e.mesos.OfferID\"?\n\x13ReviveOffersMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\"\x8f\x01\n\x0eRunTaskMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12\'\n\tframework\x18\x02 \x02(\x0b\x32\x14.mesos.FrameworkInfo\x12\x0b\n\x03pid\x18\x03 \x02(\t\x12\x1d\n\x04task\x18\x04 \x02(\x0b\x32\x0f.mesos.TaskInfo\"[\n\x0fKillTaskMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12\x1e\n\x07task_id\x18\x02 \x02(\x0b\x32\r.mesos.TaskID\"P\n\x13StatusUpdateMessage\x12,\n\x06update\x18\x01 \x02(\x0b\x32\x1c.mesos.internal.StatusUpdate\x12\x0b\n\x03pid\x18\x02 \x01(\t\"\x9e\x01\n\"StatusUpdateAcknowledgementMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\x12(\n\x0c\x66ramework_id\x18\x02 \x02(\x0b\x32\x12.mesos.FrameworkID\x12\x1e\n\x07task_id\x18\x03 \x02(\x0b\x32\r.mesos.TaskID\x12\x0c\n\x04uuid\x18\x04 \x02(\x0c\"4\n\x10LostSlaveMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\"f\n\x15ReconcileTasksMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12#\n\x08statuses\x18\x02 \x03(\x0b\x32\x11.mesos.TaskStatus\"(\n\x15\x46rameworkErrorMessage\x12\x0f\n\x07message\x18\x02 \x02(\t\"7\n\x14RegisterSlaveMessage\x12\x1f\n\x05slave\x18\x01 \x02(\x0b\x32\x10.mesos.SlaveInfo\"\xee\x01\n\x16ReregisterSlaveMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\x12\x1f\n\x05slave\x18\x02 \x02(\x0b\x32\x10.mesos.SlaveInfo\x12+\n\x0e\x65xecutor_infos\x18\x04 \x03(\x0b\x32\x13.mesos.ExecutorInfo\x12#\n\x05tasks\x18\x03 \x03(\x0b\x32\x14.mesos.internal.Task\x12?\n\x14\x63ompleted_frameworks\x18\x05 \x03(\x0b\x32!.mesos.internal.Archive.Framework\":\n\x16SlaveRegisteredMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\"<\n\x18SlaveReregisteredMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\":\n\x16UnregisterSlaveMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\"4\n\x10HeartbeatMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\"D\n\x18ShutdownFrameworkMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\"\x19\n\x17ShutdownExecutorMessage\"O\n\x16UpdateFrameworkMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12\x0b\n\x03pid\x18\x02 \x02(\t\"k\n\x17RegisterExecutorMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0b\x65xecutor_id\x18\x02 \x02(\x0b\x32\x11.mesos.ExecutorID\"\xe7\x01\n\x19\x45xecutorRegisteredMessage\x12*\n\rexecutor_info\x18\x02 \x02(\x0b\x32\x13.mesos.ExecutorInfo\x12(\n\x0c\x66ramework_id\x18\x03 \x02(\x0b\x32\x12.mesos.FrameworkID\x12,\n\x0e\x66ramework_info\x18\x04 \x02(\x0b\x32\x14.mesos.FrameworkInfo\x12 \n\x08slave_id\x18\x05 \x02(\x0b\x32\x0e.mesos.SlaveID\x12$\n\nslave_info\x18\x06 \x02(\x0b\x32\x10.mesos.SlaveInfo\"e\n\x1b\x45xecutorReregisteredMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\x12$\n\nslave_info\x18\x02 \x02(\x0b\x32\x10.mesos.SlaveInfo\"\x9b\x01\n\x15\x45xitedExecutorMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\x12(\n\x0c\x66ramework_id\x18\x02 \x02(\x0b\x32\x12.mesos.FrameworkID\x12&\n\x0b\x65xecutor_id\x18\x03 \x02(\x0b\x32\x11.mesos.ExecutorID\x12\x0e\n\x06status\x18\x04 \x02(\x05\"<\n\x18ReconnectExecutorMessage\x12 \n\x08slave_id\x18\x01 \x02(\x0b\x32\x0e.mesos.SlaveID\"\xbc\x01\n\x19ReregisterExecutorMessage\x12&\n\x0b\x65xecutor_id\x18\x01 \x02(\x0b\x32\x11.mesos.ExecutorID\x12(\n\x0c\x66ramework_id\x18\x02 \x02(\x0b\x32\x12.mesos.FrameworkID\x12\x1e\n\x05tasks\x18\x03 \x03(\x0b\x32\x0f.mesos.TaskInfo\x12-\n\x07updates\x18\x04 \x03(\x0b\x32\x1c.mesos.internal.StatusUpdate\"\'\n\x14RegisterProjdMessage\x12\x0f\n\x07project\x18\x01 \x02(\t\"$\n\x11ProjdReadyMessage\x12\x0f\n\x07project\x18\x01 \x02(\t\"D\n\x1bProjdUpdateResourcesMessage\x12%\n\nparameters\x18\x01 \x01(\x0b\x32\x11.mesos.Parameters\"C\n\x17\x46rameworkExpiredMessage\x12(\n\x0c\x66ramework_id\x18\x01 \x02(\x0b\x32\x12.mesos.FrameworkID\"\"\n\x0fShutdownMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\"\"\n\x13\x41uthenticateMessage\x12\x0b\n\x03pid\x18\x01 \x02(\t\"5\n\x1f\x41uthenticationMechanismsMessage\x12\x12\n\nmechanisms\x18\x01 \x03(\t\"=\n\x1a\x41uthenticationStartMessage\x12\x11\n\tmechanism\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\")\n\x19\x41uthenticationStepMessage\x12\x0c\n\x04\x64\x61ta\x18\x01 \x02(\x0c\" \n\x1e\x41uthenticationCompletedMessage\"\x1d\n\x1b\x41uthenticationFailedMessage\"+\n\x1a\x41uthenticationErrorMessage\x12\r\n\x05\x65rror\x18\x01 \x01(\t\"\xad\x01\n\x07\x41rchive\x12\x35\n\nframeworks\x18\x01 \x03(\x0b\x32!.mesos.internal.Archive.Framework\x1ak\n\tFramework\x12,\n\x0e\x66ramework_info\x18\x01 \x02(\x0b\x32\x14.mesos.FrameworkInfo\x12\x0b\n\x03pid\x18\x02 \x01(\t\x12#\n\x05tasks\x18\x03 \x03(\x0b\x32\x14.mesos.internal.Task')



_STATUSUPDATERECORD_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='mesos.internal.StatusUpdateRecord.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACK', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=708,
  serialized_end=735,
)


_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='mesos.internal.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mesos.internal.Task.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='mesos.internal.Task.task_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.Task.framework_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.Task.executor_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.Task.slave_id', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='mesos.internal.Task.state', index=5,
      number=6, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=6,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resources', full_name='mesos.internal.Task.resources', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='statuses', full_name='mesos.internal.Task.statuses', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=48,
  serialized_end=322,
)


_ROLEINFO = _descriptor.Descriptor(
  name='RoleInfo',
  full_name='mesos.internal.RoleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mesos.internal.RoleInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weight', full_name='mesos.internal.RoleInfo.weight', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=324,
  serialized_end=367,
)


_STATUSUPDATE = _descriptor.Descriptor(
  name='StatusUpdate',
  full_name='mesos.internal.StatusUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.StatusUpdate.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.StatusUpdate.executor_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.StatusUpdate.slave_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='mesos.internal.StatusUpdate.status', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='mesos.internal.StatusUpdate.timestamp', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='mesos.internal.StatusUpdate.uuid', index=5,
      number=6, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=370,
  serialized_end=568,
)


_STATUSUPDATERECORD = _descriptor.Descriptor(
  name='StatusUpdateRecord',
  full_name='mesos.internal.StatusUpdateRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='mesos.internal.StatusUpdateRecord.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='update', full_name='mesos.internal.StatusUpdateRecord.update', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='mesos.internal.StatusUpdateRecord.uuid', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUSUPDATERECORD_TYPE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=571,
  serialized_end=735,
)


_SUBMITSCHEDULERREQUEST = _descriptor.Descriptor(
  name='SubmitSchedulerRequest',
  full_name='mesos.internal.SubmitSchedulerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mesos.internal.SubmitSchedulerRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=737,
  serialized_end=775,
)


_SUBMITSCHEDULERRESPONSE = _descriptor.Descriptor(
  name='SubmitSchedulerResponse',
  full_name='mesos.internal.SubmitSchedulerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='okay', full_name='mesos.internal.SubmitSchedulerResponse.okay', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=777,
  serialized_end=816,
)


_EXECUTORTOFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='ExecutorToFrameworkMessage',
  full_name='mesos.internal.ExecutorToFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.ExecutorToFrameworkMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ExecutorToFrameworkMessage.framework_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.ExecutorToFrameworkMessage.executor_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='mesos.internal.ExecutorToFrameworkMessage.data', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=819,
  serialized_end=977,
)


_FRAMEWORKTOEXECUTORMESSAGE = _descriptor.Descriptor(
  name='FrameworkToExecutorMessage',
  full_name='mesos.internal.FrameworkToExecutorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.FrameworkToExecutorMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.FrameworkToExecutorMessage.framework_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.FrameworkToExecutorMessage.executor_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='mesos.internal.FrameworkToExecutorMessage.data', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=980,
  serialized_end=1138,
)


_REGISTERFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='RegisterFrameworkMessage',
  full_name='mesos.internal.RegisterFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework', full_name='mesos.internal.RegisterFrameworkMessage.framework', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1140,
  serialized_end=1207,
)


_REREGISTERFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='ReregisterFrameworkMessage',
  full_name='mesos.internal.ReregisterFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework', full_name='mesos.internal.ReregisterFrameworkMessage.framework', index=0,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='failover', full_name='mesos.internal.ReregisterFrameworkMessage.failover', index=1,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1209,
  serialized_end=1296,
)


_FRAMEWORKREGISTEREDMESSAGE = _descriptor.Descriptor(
  name='FrameworkRegisteredMessage',
  full_name='mesos.internal.FrameworkRegisteredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.FrameworkRegisteredMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='master_info', full_name='mesos.internal.FrameworkRegisteredMessage.master_info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1298,
  serialized_end=1408,
)


_FRAMEWORKREREGISTEREDMESSAGE = _descriptor.Descriptor(
  name='FrameworkReregisteredMessage',
  full_name='mesos.internal.FrameworkReregisteredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.FrameworkReregisteredMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='master_info', full_name='mesos.internal.FrameworkReregisteredMessage.master_info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1410,
  serialized_end=1522,
)


_UNREGISTERFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='UnregisterFrameworkMessage',
  full_name='mesos.internal.UnregisterFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.UnregisterFrameworkMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1524,
  serialized_end=1594,
)


_DEACTIVATEFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='DeactivateFrameworkMessage',
  full_name='mesos.internal.DeactivateFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.DeactivateFrameworkMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1596,
  serialized_end=1666,
)


_RESOURCEREQUESTMESSAGE = _descriptor.Descriptor(
  name='ResourceRequestMessage',
  full_name='mesos.internal.ResourceRequestMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ResourceRequestMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='requests', full_name='mesos.internal.ResourceRequestMessage.requests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1668,
  serialized_end=1768,
)


_RESOURCEOFFERSMESSAGE = _descriptor.Descriptor(
  name='ResourceOffersMessage',
  full_name='mesos.internal.ResourceOffersMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offers', full_name='mesos.internal.ResourceOffersMessage.offers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pids', full_name='mesos.internal.ResourceOffersMessage.pids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1770,
  serialized_end=1837,
)


_LAUNCHTASKSMESSAGE = _descriptor.Descriptor(
  name='LaunchTasksMessage',
  full_name='mesos.internal.LaunchTasksMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.LaunchTasksMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offer_id', full_name='mesos.internal.LaunchTasksMessage.offer_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='mesos.internal.LaunchTasksMessage.tasks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filters', full_name='mesos.internal.LaunchTasksMessage.filters', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offer_ids', full_name='mesos.internal.LaunchTasksMessage.offer_ids', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1840,
  serialized_end=2036,
)


_RESCINDRESOURCEOFFERMESSAGE = _descriptor.Descriptor(
  name='RescindResourceOfferMessage',
  full_name='mesos.internal.RescindResourceOfferMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offer_id', full_name='mesos.internal.RescindResourceOfferMessage.offer_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2038,
  serialized_end=2101,
)


_REVIVEOFFERSMESSAGE = _descriptor.Descriptor(
  name='ReviveOffersMessage',
  full_name='mesos.internal.ReviveOffersMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ReviveOffersMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2103,
  serialized_end=2166,
)


_RUNTASKMESSAGE = _descriptor.Descriptor(
  name='RunTaskMessage',
  full_name='mesos.internal.RunTaskMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.RunTaskMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework', full_name='mesos.internal.RunTaskMessage.framework', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='mesos.internal.RunTaskMessage.pid', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task', full_name='mesos.internal.RunTaskMessage.task', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2169,
  serialized_end=2312,
)


_KILLTASKMESSAGE = _descriptor.Descriptor(
  name='KillTaskMessage',
  full_name='mesos.internal.KillTaskMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.KillTaskMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='mesos.internal.KillTaskMessage.task_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2314,
  serialized_end=2405,
)


_STATUSUPDATEMESSAGE = _descriptor.Descriptor(
  name='StatusUpdateMessage',
  full_name='mesos.internal.StatusUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update', full_name='mesos.internal.StatusUpdateMessage.update', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='mesos.internal.StatusUpdateMessage.pid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2407,
  serialized_end=2487,
)


_STATUSUPDATEACKNOWLEDGEMENTMESSAGE = _descriptor.Descriptor(
  name='StatusUpdateAcknowledgementMessage',
  full_name='mesos.internal.StatusUpdateAcknowledgementMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.StatusUpdateAcknowledgementMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.StatusUpdateAcknowledgementMessage.framework_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='mesos.internal.StatusUpdateAcknowledgementMessage.task_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='mesos.internal.StatusUpdateAcknowledgementMessage.uuid', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2490,
  serialized_end=2648,
)


_LOSTSLAVEMESSAGE = _descriptor.Descriptor(
  name='LostSlaveMessage',
  full_name='mesos.internal.LostSlaveMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.LostSlaveMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2650,
  serialized_end=2702,
)


_RECONCILETASKSMESSAGE = _descriptor.Descriptor(
  name='ReconcileTasksMessage',
  full_name='mesos.internal.ReconcileTasksMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ReconcileTasksMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='statuses', full_name='mesos.internal.ReconcileTasksMessage.statuses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2704,
  serialized_end=2806,
)


_FRAMEWORKERRORMESSAGE = _descriptor.Descriptor(
  name='FrameworkErrorMessage',
  full_name='mesos.internal.FrameworkErrorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='mesos.internal.FrameworkErrorMessage.message', index=0,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2808,
  serialized_end=2848,
)


_REGISTERSLAVEMESSAGE = _descriptor.Descriptor(
  name='RegisterSlaveMessage',
  full_name='mesos.internal.RegisterSlaveMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave', full_name='mesos.internal.RegisterSlaveMessage.slave', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2850,
  serialized_end=2905,
)


_REREGISTERSLAVEMESSAGE = _descriptor.Descriptor(
  name='ReregisterSlaveMessage',
  full_name='mesos.internal.ReregisterSlaveMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.ReregisterSlaveMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slave', full_name='mesos.internal.ReregisterSlaveMessage.slave', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_infos', full_name='mesos.internal.ReregisterSlaveMessage.executor_infos', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='mesos.internal.ReregisterSlaveMessage.tasks', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='completed_frameworks', full_name='mesos.internal.ReregisterSlaveMessage.completed_frameworks', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2908,
  serialized_end=3146,
)


_SLAVEREGISTEREDMESSAGE = _descriptor.Descriptor(
  name='SlaveRegisteredMessage',
  full_name='mesos.internal.SlaveRegisteredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.SlaveRegisteredMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3148,
  serialized_end=3206,
)


_SLAVEREREGISTEREDMESSAGE = _descriptor.Descriptor(
  name='SlaveReregisteredMessage',
  full_name='mesos.internal.SlaveReregisteredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.SlaveReregisteredMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3208,
  serialized_end=3268,
)


_UNREGISTERSLAVEMESSAGE = _descriptor.Descriptor(
  name='UnregisterSlaveMessage',
  full_name='mesos.internal.UnregisterSlaveMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.UnregisterSlaveMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3270,
  serialized_end=3328,
)


_HEARTBEATMESSAGE = _descriptor.Descriptor(
  name='HeartbeatMessage',
  full_name='mesos.internal.HeartbeatMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.HeartbeatMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3330,
  serialized_end=3382,
)


_SHUTDOWNFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='ShutdownFrameworkMessage',
  full_name='mesos.internal.ShutdownFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ShutdownFrameworkMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3384,
  serialized_end=3452,
)


_SHUTDOWNEXECUTORMESSAGE = _descriptor.Descriptor(
  name='ShutdownExecutorMessage',
  full_name='mesos.internal.ShutdownExecutorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3454,
  serialized_end=3479,
)


_UPDATEFRAMEWORKMESSAGE = _descriptor.Descriptor(
  name='UpdateFrameworkMessage',
  full_name='mesos.internal.UpdateFrameworkMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.UpdateFrameworkMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='mesos.internal.UpdateFrameworkMessage.pid', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3481,
  serialized_end=3560,
)


_REGISTEREXECUTORMESSAGE = _descriptor.Descriptor(
  name='RegisterExecutorMessage',
  full_name='mesos.internal.RegisterExecutorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.RegisterExecutorMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.RegisterExecutorMessage.executor_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3562,
  serialized_end=3669,
)


_EXECUTORREGISTEREDMESSAGE = _descriptor.Descriptor(
  name='ExecutorRegisteredMessage',
  full_name='mesos.internal.ExecutorRegisteredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executor_info', full_name='mesos.internal.ExecutorRegisteredMessage.executor_info', index=0,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ExecutorRegisteredMessage.framework_id', index=1,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_info', full_name='mesos.internal.ExecutorRegisteredMessage.framework_info', index=2,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.ExecutorRegisteredMessage.slave_id', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slave_info', full_name='mesos.internal.ExecutorRegisteredMessage.slave_info', index=4,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3672,
  serialized_end=3903,
)


_EXECUTORREREGISTEREDMESSAGE = _descriptor.Descriptor(
  name='ExecutorReregisteredMessage',
  full_name='mesos.internal.ExecutorReregisteredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.ExecutorReregisteredMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='slave_info', full_name='mesos.internal.ExecutorReregisteredMessage.slave_info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3905,
  serialized_end=4006,
)


_EXITEDEXECUTORMESSAGE = _descriptor.Descriptor(
  name='ExitedExecutorMessage',
  full_name='mesos.internal.ExitedExecutorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.ExitedExecutorMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ExitedExecutorMessage.framework_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.ExitedExecutorMessage.executor_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status', full_name='mesos.internal.ExitedExecutorMessage.status', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4009,
  serialized_end=4164,
)


_RECONNECTEXECUTORMESSAGE = _descriptor.Descriptor(
  name='ReconnectExecutorMessage',
  full_name='mesos.internal.ReconnectExecutorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='slave_id', full_name='mesos.internal.ReconnectExecutorMessage.slave_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4166,
  serialized_end=4226,
)


_REREGISTEREXECUTORMESSAGE = _descriptor.Descriptor(
  name='ReregisterExecutorMessage',
  full_name='mesos.internal.ReregisterExecutorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executor_id', full_name='mesos.internal.ReregisterExecutorMessage.executor_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.ReregisterExecutorMessage.framework_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='mesos.internal.ReregisterExecutorMessage.tasks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='updates', full_name='mesos.internal.ReregisterExecutorMessage.updates', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4229,
  serialized_end=4417,
)


_REGISTERPROJDMESSAGE = _descriptor.Descriptor(
  name='RegisterProjdMessage',
  full_name='mesos.internal.RegisterProjdMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='mesos.internal.RegisterProjdMessage.project', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4419,
  serialized_end=4458,
)


_PROJDREADYMESSAGE = _descriptor.Descriptor(
  name='ProjdReadyMessage',
  full_name='mesos.internal.ProjdReadyMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='mesos.internal.ProjdReadyMessage.project', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4460,
  serialized_end=4496,
)


_PROJDUPDATERESOURCESMESSAGE = _descriptor.Descriptor(
  name='ProjdUpdateResourcesMessage',
  full_name='mesos.internal.ProjdUpdateResourcesMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='mesos.internal.ProjdUpdateResourcesMessage.parameters', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4498,
  serialized_end=4566,
)


_FRAMEWORKEXPIREDMESSAGE = _descriptor.Descriptor(
  name='FrameworkExpiredMessage',
  full_name='mesos.internal.FrameworkExpiredMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_id', full_name='mesos.internal.FrameworkExpiredMessage.framework_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4568,
  serialized_end=4635,
)


_SHUTDOWNMESSAGE = _descriptor.Descriptor(
  name='ShutdownMessage',
  full_name='mesos.internal.ShutdownMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='mesos.internal.ShutdownMessage.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4637,
  serialized_end=4671,
)


_AUTHENTICATEMESSAGE = _descriptor.Descriptor(
  name='AuthenticateMessage',
  full_name='mesos.internal.AuthenticateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='mesos.internal.AuthenticateMessage.pid', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4673,
  serialized_end=4707,
)


_AUTHENTICATIONMECHANISMSMESSAGE = _descriptor.Descriptor(
  name='AuthenticationMechanismsMessage',
  full_name='mesos.internal.AuthenticationMechanismsMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mechanisms', full_name='mesos.internal.AuthenticationMechanismsMessage.mechanisms', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4709,
  serialized_end=4762,
)


_AUTHENTICATIONSTARTMESSAGE = _descriptor.Descriptor(
  name='AuthenticationStartMessage',
  full_name='mesos.internal.AuthenticationStartMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mechanism', full_name='mesos.internal.AuthenticationStartMessage.mechanism', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='mesos.internal.AuthenticationStartMessage.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4764,
  serialized_end=4825,
)


_AUTHENTICATIONSTEPMESSAGE = _descriptor.Descriptor(
  name='AuthenticationStepMessage',
  full_name='mesos.internal.AuthenticationStepMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='mesos.internal.AuthenticationStepMessage.data', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4827,
  serialized_end=4868,
)


_AUTHENTICATIONCOMPLETEDMESSAGE = _descriptor.Descriptor(
  name='AuthenticationCompletedMessage',
  full_name='mesos.internal.AuthenticationCompletedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4870,
  serialized_end=4902,
)


_AUTHENTICATIONFAILEDMESSAGE = _descriptor.Descriptor(
  name='AuthenticationFailedMessage',
  full_name='mesos.internal.AuthenticationFailedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4904,
  serialized_end=4933,
)


_AUTHENTICATIONERRORMESSAGE = _descriptor.Descriptor(
  name='AuthenticationErrorMessage',
  full_name='mesos.internal.AuthenticationErrorMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='mesos.internal.AuthenticationErrorMessage.error', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4935,
  serialized_end=4978,
)


_ARCHIVE_FRAMEWORK = _descriptor.Descriptor(
  name='Framework',
  full_name='mesos.internal.Archive.Framework',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='framework_info', full_name='mesos.internal.Archive.Framework.framework_info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pid', full_name='mesos.internal.Archive.Framework.pid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='mesos.internal.Archive.Framework.tasks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=5047,
  serialized_end=5154,
)

_ARCHIVE = _descriptor.Descriptor(
  name='Archive',
  full_name='mesos.internal.Archive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frameworks', full_name='mesos.internal.Archive.frameworks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ARCHIVE_FRAMEWORK, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4981,
  serialized_end=5154,
)

_TASK.fields_by_name['task_id'].message_type = mesos_pb2._TASKID
_TASK.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_TASK.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_TASK.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_TASK.fields_by_name['state'].enum_type = mesos_pb2._TASKSTATE
_TASK.fields_by_name['resources'].message_type = mesos_pb2._RESOURCE
_TASK.fields_by_name['statuses'].message_type = mesos_pb2._TASKSTATUS
_STATUSUPDATE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_STATUSUPDATE.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_STATUSUPDATE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_STATUSUPDATE.fields_by_name['status'].message_type = mesos_pb2._TASKSTATUS
_STATUSUPDATERECORD.fields_by_name['type'].enum_type = _STATUSUPDATERECORD_TYPE
_STATUSUPDATERECORD.fields_by_name['update'].message_type = _STATUSUPDATE
_STATUSUPDATERECORD_TYPE.containing_type = _STATUSUPDATERECORD;
_EXECUTORTOFRAMEWORKMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_EXECUTORTOFRAMEWORKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_EXECUTORTOFRAMEWORKMESSAGE.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_FRAMEWORKTOEXECUTORMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_FRAMEWORKTOEXECUTORMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_FRAMEWORKTOEXECUTORMESSAGE.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_REGISTERFRAMEWORKMESSAGE.fields_by_name['framework'].message_type = mesos_pb2._FRAMEWORKINFO
_REREGISTERFRAMEWORKMESSAGE.fields_by_name['framework'].message_type = mesos_pb2._FRAMEWORKINFO
_FRAMEWORKREGISTEREDMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_FRAMEWORKREGISTEREDMESSAGE.fields_by_name['master_info'].message_type = mesos_pb2._MASTERINFO
_FRAMEWORKREREGISTEREDMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_FRAMEWORKREREGISTEREDMESSAGE.fields_by_name['master_info'].message_type = mesos_pb2._MASTERINFO
_UNREGISTERFRAMEWORKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_DEACTIVATEFRAMEWORKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_RESOURCEREQUESTMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_RESOURCEREQUESTMESSAGE.fields_by_name['requests'].message_type = mesos_pb2._REQUEST
_RESOURCEOFFERSMESSAGE.fields_by_name['offers'].message_type = mesos_pb2._OFFER
_LAUNCHTASKSMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_LAUNCHTASKSMESSAGE.fields_by_name['offer_id'].message_type = mesos_pb2._OFFERID
_LAUNCHTASKSMESSAGE.fields_by_name['tasks'].message_type = mesos_pb2._TASKINFO
_LAUNCHTASKSMESSAGE.fields_by_name['filters'].message_type = mesos_pb2._FILTERS
_LAUNCHTASKSMESSAGE.fields_by_name['offer_ids'].message_type = mesos_pb2._OFFERID
_RESCINDRESOURCEOFFERMESSAGE.fields_by_name['offer_id'].message_type = mesos_pb2._OFFERID
_REVIVEOFFERSMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_RUNTASKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_RUNTASKMESSAGE.fields_by_name['framework'].message_type = mesos_pb2._FRAMEWORKINFO
_RUNTASKMESSAGE.fields_by_name['task'].message_type = mesos_pb2._TASKINFO
_KILLTASKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_KILLTASKMESSAGE.fields_by_name['task_id'].message_type = mesos_pb2._TASKID
_STATUSUPDATEMESSAGE.fields_by_name['update'].message_type = _STATUSUPDATE
_STATUSUPDATEACKNOWLEDGEMENTMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_STATUSUPDATEACKNOWLEDGEMENTMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_STATUSUPDATEACKNOWLEDGEMENTMESSAGE.fields_by_name['task_id'].message_type = mesos_pb2._TASKID
_LOSTSLAVEMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_RECONCILETASKSMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_RECONCILETASKSMESSAGE.fields_by_name['statuses'].message_type = mesos_pb2._TASKSTATUS
_REGISTERSLAVEMESSAGE.fields_by_name['slave'].message_type = mesos_pb2._SLAVEINFO
_REREGISTERSLAVEMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_REREGISTERSLAVEMESSAGE.fields_by_name['slave'].message_type = mesos_pb2._SLAVEINFO
_REREGISTERSLAVEMESSAGE.fields_by_name['executor_infos'].message_type = mesos_pb2._EXECUTORINFO
_REREGISTERSLAVEMESSAGE.fields_by_name['tasks'].message_type = _TASK
_REREGISTERSLAVEMESSAGE.fields_by_name['completed_frameworks'].message_type = _ARCHIVE_FRAMEWORK
_SLAVEREGISTEREDMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_SLAVEREREGISTEREDMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_UNREGISTERSLAVEMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_HEARTBEATMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_SHUTDOWNFRAMEWORKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_UPDATEFRAMEWORKMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_REGISTEREXECUTORMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_REGISTEREXECUTORMESSAGE.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_EXECUTORREGISTEREDMESSAGE.fields_by_name['executor_info'].message_type = mesos_pb2._EXECUTORINFO
_EXECUTORREGISTEREDMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_EXECUTORREGISTEREDMESSAGE.fields_by_name['framework_info'].message_type = mesos_pb2._FRAMEWORKINFO
_EXECUTORREGISTEREDMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_EXECUTORREGISTEREDMESSAGE.fields_by_name['slave_info'].message_type = mesos_pb2._SLAVEINFO
_EXECUTORREREGISTEREDMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_EXECUTORREREGISTEREDMESSAGE.fields_by_name['slave_info'].message_type = mesos_pb2._SLAVEINFO
_EXITEDEXECUTORMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_EXITEDEXECUTORMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_EXITEDEXECUTORMESSAGE.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_RECONNECTEXECUTORMESSAGE.fields_by_name['slave_id'].message_type = mesos_pb2._SLAVEID
_REREGISTEREXECUTORMESSAGE.fields_by_name['executor_id'].message_type = mesos_pb2._EXECUTORID
_REREGISTEREXECUTORMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_REREGISTEREXECUTORMESSAGE.fields_by_name['tasks'].message_type = mesos_pb2._TASKINFO
_REREGISTEREXECUTORMESSAGE.fields_by_name['updates'].message_type = _STATUSUPDATE
_PROJDUPDATERESOURCESMESSAGE.fields_by_name['parameters'].message_type = mesos_pb2._PARAMETERS
_FRAMEWORKEXPIREDMESSAGE.fields_by_name['framework_id'].message_type = mesos_pb2._FRAMEWORKID
_ARCHIVE_FRAMEWORK.fields_by_name['framework_info'].message_type = mesos_pb2._FRAMEWORKINFO
_ARCHIVE_FRAMEWORK.fields_by_name['tasks'].message_type = _TASK
_ARCHIVE_FRAMEWORK.containing_type = _ARCHIVE;
_ARCHIVE.fields_by_name['frameworks'].message_type = _ARCHIVE_FRAMEWORK
DESCRIPTOR.message_types_by_name['Task'] = _TASK
DESCRIPTOR.message_types_by_name['RoleInfo'] = _ROLEINFO
DESCRIPTOR.message_types_by_name['StatusUpdate'] = _STATUSUPDATE
DESCRIPTOR.message_types_by_name['StatusUpdateRecord'] = _STATUSUPDATERECORD
DESCRIPTOR.message_types_by_name['SubmitSchedulerRequest'] = _SUBMITSCHEDULERREQUEST
DESCRIPTOR.message_types_by_name['SubmitSchedulerResponse'] = _SUBMITSCHEDULERRESPONSE
DESCRIPTOR.message_types_by_name['ExecutorToFrameworkMessage'] = _EXECUTORTOFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['FrameworkToExecutorMessage'] = _FRAMEWORKTOEXECUTORMESSAGE
DESCRIPTOR.message_types_by_name['RegisterFrameworkMessage'] = _REGISTERFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['ReregisterFrameworkMessage'] = _REREGISTERFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['FrameworkRegisteredMessage'] = _FRAMEWORKREGISTEREDMESSAGE
DESCRIPTOR.message_types_by_name['FrameworkReregisteredMessage'] = _FRAMEWORKREREGISTEREDMESSAGE
DESCRIPTOR.message_types_by_name['UnregisterFrameworkMessage'] = _UNREGISTERFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['DeactivateFrameworkMessage'] = _DEACTIVATEFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['ResourceRequestMessage'] = _RESOURCEREQUESTMESSAGE
DESCRIPTOR.message_types_by_name['ResourceOffersMessage'] = _RESOURCEOFFERSMESSAGE
DESCRIPTOR.message_types_by_name['LaunchTasksMessage'] = _LAUNCHTASKSMESSAGE
DESCRIPTOR.message_types_by_name['RescindResourceOfferMessage'] = _RESCINDRESOURCEOFFERMESSAGE
DESCRIPTOR.message_types_by_name['ReviveOffersMessage'] = _REVIVEOFFERSMESSAGE
DESCRIPTOR.message_types_by_name['RunTaskMessage'] = _RUNTASKMESSAGE
DESCRIPTOR.message_types_by_name['KillTaskMessage'] = _KILLTASKMESSAGE
DESCRIPTOR.message_types_by_name['StatusUpdateMessage'] = _STATUSUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['StatusUpdateAcknowledgementMessage'] = _STATUSUPDATEACKNOWLEDGEMENTMESSAGE
DESCRIPTOR.message_types_by_name['LostSlaveMessage'] = _LOSTSLAVEMESSAGE
DESCRIPTOR.message_types_by_name['ReconcileTasksMessage'] = _RECONCILETASKSMESSAGE
DESCRIPTOR.message_types_by_name['FrameworkErrorMessage'] = _FRAMEWORKERRORMESSAGE
DESCRIPTOR.message_types_by_name['RegisterSlaveMessage'] = _REGISTERSLAVEMESSAGE
DESCRIPTOR.message_types_by_name['ReregisterSlaveMessage'] = _REREGISTERSLAVEMESSAGE
DESCRIPTOR.message_types_by_name['SlaveRegisteredMessage'] = _SLAVEREGISTEREDMESSAGE
DESCRIPTOR.message_types_by_name['SlaveReregisteredMessage'] = _SLAVEREREGISTEREDMESSAGE
DESCRIPTOR.message_types_by_name['UnregisterSlaveMessage'] = _UNREGISTERSLAVEMESSAGE
DESCRIPTOR.message_types_by_name['HeartbeatMessage'] = _HEARTBEATMESSAGE
DESCRIPTOR.message_types_by_name['ShutdownFrameworkMessage'] = _SHUTDOWNFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['ShutdownExecutorMessage'] = _SHUTDOWNEXECUTORMESSAGE
DESCRIPTOR.message_types_by_name['UpdateFrameworkMessage'] = _UPDATEFRAMEWORKMESSAGE
DESCRIPTOR.message_types_by_name['RegisterExecutorMessage'] = _REGISTEREXECUTORMESSAGE
DESCRIPTOR.message_types_by_name['ExecutorRegisteredMessage'] = _EXECUTORREGISTEREDMESSAGE
DESCRIPTOR.message_types_by_name['ExecutorReregisteredMessage'] = _EXECUTORREREGISTEREDMESSAGE
DESCRIPTOR.message_types_by_name['ExitedExecutorMessage'] = _EXITEDEXECUTORMESSAGE
DESCRIPTOR.message_types_by_name['ReconnectExecutorMessage'] = _RECONNECTEXECUTORMESSAGE
DESCRIPTOR.message_types_by_name['ReregisterExecutorMessage'] = _REREGISTEREXECUTORMESSAGE
DESCRIPTOR.message_types_by_name['RegisterProjdMessage'] = _REGISTERPROJDMESSAGE
DESCRIPTOR.message_types_by_name['ProjdReadyMessage'] = _PROJDREADYMESSAGE
DESCRIPTOR.message_types_by_name['ProjdUpdateResourcesMessage'] = _PROJDUPDATERESOURCESMESSAGE
DESCRIPTOR.message_types_by_name['FrameworkExpiredMessage'] = _FRAMEWORKEXPIREDMESSAGE
DESCRIPTOR.message_types_by_name['ShutdownMessage'] = _SHUTDOWNMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticateMessage'] = _AUTHENTICATEMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticationMechanismsMessage'] = _AUTHENTICATIONMECHANISMSMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticationStartMessage'] = _AUTHENTICATIONSTARTMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticationStepMessage'] = _AUTHENTICATIONSTEPMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticationCompletedMessage'] = _AUTHENTICATIONCOMPLETEDMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticationFailedMessage'] = _AUTHENTICATIONFAILEDMESSAGE
DESCRIPTOR.message_types_by_name['AuthenticationErrorMessage'] = _AUTHENTICATIONERRORMESSAGE
DESCRIPTOR.message_types_by_name['Archive'] = _ARCHIVE

class Task(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TASK

  # @@protoc_insertion_point(class_scope:mesos.internal.Task)

class RoleInfo(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _ROLEINFO

  # @@protoc_insertion_point(class_scope:mesos.internal.RoleInfo)

class StatusUpdate(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _STATUSUPDATE

  # @@protoc_insertion_point(class_scope:mesos.internal.StatusUpdate)

class StatusUpdateRecord(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _STATUSUPDATERECORD

  # @@protoc_insertion_point(class_scope:mesos.internal.StatusUpdateRecord)

class SubmitSchedulerRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SUBMITSCHEDULERREQUEST

  # @@protoc_insertion_point(class_scope:mesos.internal.SubmitSchedulerRequest)

class SubmitSchedulerResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SUBMITSCHEDULERRESPONSE

  # @@protoc_insertion_point(class_scope:mesos.internal.SubmitSchedulerResponse)

class ExecutorToFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _EXECUTORTOFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ExecutorToFrameworkMessage)

class FrameworkToExecutorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FRAMEWORKTOEXECUTORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.FrameworkToExecutorMessage)

class RegisterFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REGISTERFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.RegisterFrameworkMessage)

class ReregisterFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REREGISTERFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ReregisterFrameworkMessage)

class FrameworkRegisteredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FRAMEWORKREGISTEREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.FrameworkRegisteredMessage)

class FrameworkReregisteredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FRAMEWORKREREGISTEREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.FrameworkReregisteredMessage)

class UnregisterFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UNREGISTERFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.UnregisterFrameworkMessage)

class DeactivateFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DEACTIVATEFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.DeactivateFrameworkMessage)

class ResourceRequestMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RESOURCEREQUESTMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ResourceRequestMessage)

class ResourceOffersMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RESOURCEOFFERSMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ResourceOffersMessage)

class LaunchTasksMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _LAUNCHTASKSMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.LaunchTasksMessage)

class RescindResourceOfferMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RESCINDRESOURCEOFFERMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.RescindResourceOfferMessage)

class ReviveOffersMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REVIVEOFFERSMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ReviveOffersMessage)

class RunTaskMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RUNTASKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.RunTaskMessage)

class KillTaskMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _KILLTASKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.KillTaskMessage)

class StatusUpdateMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _STATUSUPDATEMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.StatusUpdateMessage)

class StatusUpdateAcknowledgementMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _STATUSUPDATEACKNOWLEDGEMENTMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.StatusUpdateAcknowledgementMessage)

class LostSlaveMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _LOSTSLAVEMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.LostSlaveMessage)

class ReconcileTasksMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RECONCILETASKSMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ReconcileTasksMessage)

class FrameworkErrorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FRAMEWORKERRORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.FrameworkErrorMessage)

class RegisterSlaveMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REGISTERSLAVEMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.RegisterSlaveMessage)

class ReregisterSlaveMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REREGISTERSLAVEMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ReregisterSlaveMessage)

class SlaveRegisteredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SLAVEREGISTEREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.SlaveRegisteredMessage)

class SlaveReregisteredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SLAVEREREGISTEREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.SlaveReregisteredMessage)

class UnregisterSlaveMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UNREGISTERSLAVEMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.UnregisterSlaveMessage)

class HeartbeatMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _HEARTBEATMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.HeartbeatMessage)

class ShutdownFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SHUTDOWNFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ShutdownFrameworkMessage)

class ShutdownExecutorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SHUTDOWNEXECUTORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ShutdownExecutorMessage)

class UpdateFrameworkMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPDATEFRAMEWORKMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.UpdateFrameworkMessage)

class RegisterExecutorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REGISTEREXECUTORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.RegisterExecutorMessage)

class ExecutorRegisteredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _EXECUTORREGISTEREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ExecutorRegisteredMessage)

class ExecutorReregisteredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _EXECUTORREREGISTEREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ExecutorReregisteredMessage)

class ExitedExecutorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _EXITEDEXECUTORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ExitedExecutorMessage)

class ReconnectExecutorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RECONNECTEXECUTORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ReconnectExecutorMessage)

class ReregisterExecutorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REREGISTEREXECUTORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ReregisterExecutorMessage)

class RegisterProjdMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _REGISTERPROJDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.RegisterProjdMessage)

class ProjdReadyMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PROJDREADYMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ProjdReadyMessage)

class ProjdUpdateResourcesMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PROJDUPDATERESOURCESMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ProjdUpdateResourcesMessage)

class FrameworkExpiredMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FRAMEWORKEXPIREDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.FrameworkExpiredMessage)

class ShutdownMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SHUTDOWNMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.ShutdownMessage)

class AuthenticateMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATEMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticateMessage)

class AuthenticationMechanismsMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATIONMECHANISMSMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticationMechanismsMessage)

class AuthenticationStartMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATIONSTARTMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticationStartMessage)

class AuthenticationStepMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATIONSTEPMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticationStepMessage)

class AuthenticationCompletedMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATIONCOMPLETEDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticationCompletedMessage)

class AuthenticationFailedMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATIONFAILEDMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticationFailedMessage)

class AuthenticationErrorMessage(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _AUTHENTICATIONERRORMESSAGE

  # @@protoc_insertion_point(class_scope:mesos.internal.AuthenticationErrorMessage)

class Archive(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class Framework(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _ARCHIVE_FRAMEWORK

    # @@protoc_insertion_point(class_scope:mesos.internal.Archive.Framework)
  DESCRIPTOR = _ARCHIVE

  # @@protoc_insertion_point(class_scope:mesos.internal.Archive)


# @@protoc_insertion_point(module_scope)
